@@ -10,7 +10,9 @@ pub mod clock;
 pub mod core;
 pub mod dinoparc;
 pub mod dinorpg;
+pub mod dns;
 pub mod email;
+pub mod forum;
 pub mod hammerfest;
 pub mod link;
 pub mod oauth;
