@@ -87,6 +87,26 @@ pub struct GetShortUserOptions {
   pub time: Option<Instant>,
 }
 
+impl From<UserRef> for GetShortUserOptions {
+  fn from(r#ref: UserRef) -> Self {
+    Self { r#ref, time: None }
+  }
+}
+
+impl From<UserIdRef> for GetShortUserOptions {
+  fn from(r: UserIdRef) -> Self {
+    let r: UserRef = r.into();
+    r.into()
+  }
+}
+
+impl From<UserId> for GetShortUserOptions {
+  fn from(id: UserId) -> Self {
+    let r: UserRef = id.into();
+    r.into()
+  }
+}
+
 #[cfg_attr(feature = "_serde", derive(Serialize, Deserialize), serde(untagged))]
 #[derive(Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub enum GetUserResult {
@@ -103,6 +123,12 @@ pub struct ShortUser {
   pub display_name: UserDisplayNameVersions,
 }
 
+impl ShortUser {
+  pub const fn as_ref(&self) -> UserIdRef {
+    UserIdRef { id: self.id }
+  }
+}
+
 impl From<SimpleUser> for ShortUser {
   fn from(user: SimpleUser) -> Self {
     Self {
@@ -227,6 +253,30 @@ pub enum UserRef {
   Email(UserEmailRef),
 }
 
+impl From<UserId> for UserRef {
+  fn from(id: UserId) -> Self {
+    Self::Id(id.into())
+  }
+}
+
+impl From<UserIdRef> for UserRef {
+  fn from(r: UserIdRef) -> Self {
+    Self::Id(r)
+  }
+}
+
+impl From<UserUsernameRef> for UserRef {
+  fn from(r: UserUsernameRef) -> Self {
+    Self::Username(r)
+  }
+}
+
+impl From<UserEmailRef> for UserRef {
+  fn from(r: UserEmailRef) -> Self {
+    Self::Email(r)
+  }
+}
+
 declare_new_string! {
   pub struct Username(String);
   pub type ParseError = UsernameParseError;
